==> open-cluster-management-apps-model-6.3.0-sources.jar: io/fabric8/openclustermanagement/api/model/multicloudoperatorschannel/apps/v1/ChannelListFluent.java <==
package io.fabric8.openclustermanagement.api.model.multicloudoperatorschannel.apps.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface ChannelListFluent<A extends ChannelListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(Integer index,Channel item);
  public A setToItems(Integer index,Channel item);
  public A addToItems(io.fabric8.openclustermanagement.api.model.multicloudoperatorschannel.apps.v1.Channel... items);
  public A addAllToItems(Collection<Channel> items);
  public A removeFromItems(io.fabric8.openclustermanagement.api.model.multicloudoperatorschannel.apps.v1.Channel... items);
  public A removeAllFromItems(Collection<Channel> items);
  public A removeMatchingFromItems(Predicate<ChannelBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<Channel> getItems();
  public List<Channel> buildItems();
  public Channel buildItem(Integer index);
  public Channel buildFirstItem();
  public Channel buildLastItem();
  public Channel buildMatchingItem(Predicate<ChannelBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<ChannelBuilder> predicate);
  public A withItems(List<Channel> items);
  public A withItems(io.fabric8.openclustermanagement.api.model.multicloudoperatorschannel.apps.v1.Channel... items);
  public Boolean hasItems();
  public ChannelListFluent.ItemsNested<A> addNewItem();
  public ChannelListFluent.ItemsNested<A> addNewItemLike(Channel item);
  public ChannelListFluent.ItemsNested<A> setNewItemLike(Integer index,Channel item);
  public ChannelListFluent.ItemsNested<A> editItem(Integer index);
  public ChannelListFluent.ItemsNested<A> editFirstItem();
  public ChannelListFluent.ItemsNested<A> editLastItem();
  public ChannelListFluent.ItemsNested<A> editMatchingItem(Predicate<ChannelBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,ChannelFluent<ChannelListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}

==> open-cluster-management-apps-model-6.7.1-sources.jar: io/fabric8/openclustermanagement/api/model/multicloudoperatorschannel/apps/v1/ChannelListFluent.java <==
package io.fabric8.openclustermanagement.api.model.multicloudoperatorschannel.apps.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface ChannelListFluent<A extends ChannelListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(int index,Channel item);
  public A setToItems(int index,Channel item);
  public A addToItems(io.fabric8.openclustermanagement.api.model.multicloudoperatorschannel.apps.v1.Channel... items);
  public A addAllToItems(Collection<Channel> items);
  public A removeFromItems(io.fabric8.openclustermanagement.api.model.multicloudoperatorschannel.apps.v1.Channel... items);
  public A removeAllFromItems(Collection<Channel> items);
  public A removeMatchingFromItems(Predicate<ChannelBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<Channel> getItems();
  public List<Channel> buildItems();
  public Channel buildItem(int index);
  public Channel buildFirstItem();
  public Channel buildLastItem();
  public Channel buildMatchingItem(Predicate<ChannelBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<ChannelBuilder> predicate);
  public A withItems(List<Channel> items);
  public A withItems(io.fabric8.openclustermanagement.api.model.multicloudoperatorschannel.apps.v1.Channel... items);
  public Boolean hasItems();
  public ChannelListFluent.ItemsNested<A> addNewItem();
  public ChannelListFluent.ItemsNested<A> addNewItemLike(Channel item);
  public ChannelListFluent.ItemsNested<A> setNewItemLike(int index,Channel item);
  public ChannelListFluent.ItemsNested<A> editItem(int index);
  public ChannelListFluent.ItemsNested<A> editFirstItem();
  public ChannelListFluent.ItemsNested<A> editLastItem();
  public ChannelListFluent.ItemsNested<A> editMatchingItem(Predicate<ChannelBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,ChannelFluent<ChannelListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}
